@@ -104,6 +104,17 @@ class NotificationManagerTest : public QObject
 
     typedef QList<NotificationSubscriber *> NSList;
 
+
+    Protocol::FetchItemsResponse itemResponse(qint64 id, const QString &rid, const QString &rrev, const QString &mt)
+    {
+        Protocol::FetchItemsResponse item;
+        item.setId(id);
+        item.setRemoteId(rid);
+        item.setRemoteRevision(rrev);
+        item.setMimeType(mt);
+        return item;
+    }
+
 private Q_SLOTS:
     void testSourceFilter_data()
     {
@@ -135,7 +146,7 @@ private Q_SLOTS:
                 << false;
 
         itemMsg = Protocol::ItemChangeNotificationPtr::create(*itemMsg);
-        itemMsg->setItems({ { 1, QString(), QString(), QStringLiteral("message/rfc822") } });
+        itemMsg->setItems({ itemResponse(1, QString(), QString(), QStringLiteral("message/rfc822")) });
         QTest::newRow("monitorAll vs notification with one item")
                 << true
                 << EmptyList(Entity::Id)
@@ -181,8 +192,10 @@ private Q_SLOTS:
         // Simulate adding a new resource
         auto colMsg = Protocol::CollectionChangeNotificationPtr::create();
         colMsg->setOperation(Protocol::CollectionChangeNotification::Add);
-        colMsg->setId(1);
-        colMsg->setRemoteId(QStringLiteral("imap://user@some.domain/"));
+        Protocol::FetchCollectionsResponse col;
+        col.setId(1);
+        col.setRemoteId(QStringLiteral("imap://user@some.domain/"));
+        colMsg->setCollection(std::move(col));
         colMsg->setParentCollection(0);
         colMsg->setSessionId("akonadi_imap_resource_0");
         colMsg->setResource("akonadi_imap_resource_0");
@@ -203,7 +216,7 @@ private Q_SLOTS:
         itemMsg->setParentCollection(1);
         itemMsg->setParentDestCollection(2);
         itemMsg->setSessionId("kmail");
-        itemMsg->setItems({ { 10, QStringLiteral("123"), QStringLiteral("1"), QStringLiteral("message/rfc822") } });
+        itemMsg->setItems({ itemResponse(10, QStringLiteral("123"), QStringLiteral("1"), QStringLiteral("message/rfc822")) });
         QTest::newRow("inter-resource move, source source")
                 << false
                 << EmptyList(Entity::Id)
@@ -242,8 +255,8 @@ private Q_SLOTS:
         itemMsg->setParentDestCollection(2);
         itemMsg->setSessionId("kmail");
         itemMsg->setItems({
-            { 10, QStringLiteral("123"), QStringLiteral("1"), QStringLiteral("message/rfc822") },
-            { 11, QStringLiteral("456"), QStringLiteral("1"), QStringLiteral("message/rfc822") } });
+            itemResponse(10, QStringLiteral("123"), QStringLiteral("1"), QStringLiteral("message/rfc822")),
+            itemResponse(11, QStringLiteral("456"), QStringLiteral("1"), QStringLiteral("message/rfc822")) });
         QTest::newRow("intra-resource move, owning resource")
                 << false
                 << EmptyList(Entity::Id)
@@ -274,7 +287,7 @@ private Q_SLOTS:
         itemMsg->setSessionId("randomSession");
         itemMsg->setResource("randomResource");
         itemMsg->setParentCollection(1);
-        itemMsg->setItems({ { 10, QString(), QString(), QStringLiteral("message/rfc822") } });
+        itemMsg->setItems({ itemResponse(10, QString(), QString(), QStringLiteral("message/rfc822")) });
         QTest::newRow("new mail for mailfilter or maildispatcher")
                 << false
                 << List(Entity::Id, 0)
@@ -289,8 +302,12 @@ private Q_SLOTS:
         tagMsg->setOperation(Protocol::TagChangeNotification::Remove);
         tagMsg->setSessionId("randomSession");
         tagMsg->setResource("akonadi_random_resource_0");
-        tagMsg->setId(1);
-        tagMsg->setRemoteId(QStringLiteral("TAG"));
+        {
+            Protocol::FetchTagsResponse tagMsgTag;
+            tagMsgTag.setId(1);
+            tagMsgTag.setRemoteId("TAG");
+            tagMsg->setTag(std::move(tagMsgTag));
+        }
         QTest::newRow("Tag removal - resource notification - matching resource source")
                 << false
                 << EmptyList(Entity::Id)
@@ -314,8 +331,12 @@ private Q_SLOTS:
         tagMsg = Protocol::TagChangeNotificationPtr::create();
         tagMsg->setOperation(Protocol::TagChangeNotification::Remove);
         tagMsg->setSessionId("randomSession");
-        tagMsg->setId(1);
-        tagMsg->setRemoteId(QStringLiteral("TAG"));
+        {
+            Protocol::FetchTagsResponse tagMsgTag;
+            tagMsgTag.setId(1);
+            tagMsgTag.setRemoteId("TAG");
+            tagMsg->setTag(std::move(tagMsgTag));
+        }
         QTest::newRow("Tag removal - client notification - client source")
                 << false
                 << EmptyList(Entity::Id)
