@@ -32,7 +32,6 @@
 #include "akonadicontrol_debug.h"
 
 #include <private/protocol_p.h>
-#include <private/xdgbasedirs_p.h>
 #include <private/instance_p.h>
 #include <private/standarddirs_p.h>
 #include <private/dbus_p.h>
@@ -71,7 +70,7 @@ AgentManager::AgentManager(bool verbose, QObject *parent)
         qFatal("akonadiserver already running!");
     }
 
-    const QSettings settings(Akonadi::StandardDirs::agentConfigFile(Akonadi::XdgBaseDirs::ReadOnly), QSettings::IniFormat);
+    const QSettings settings(Akonadi::StandardDirs::agentsConfigFile(Akonadi::StandardDirs::ReadOnly), QSettings::IniFormat);
     mAgentServerEnabled = settings.value(QStringLiteral("AgentServer/Enabled"), enableAgentServerDefault).toBool();
 
     QStringList serviceArgs;
@@ -94,7 +93,7 @@ AgentManager::AgentManager(bool verbose, QObject *parent)
     }
 
 #ifndef QT_NO_DEBUG
-    connect(mAgentWatcher, SIGNAL(fileChanged(QString)), SLOT(agentExeChanged(QString)));
+    connect(mAgentWatcher, &QFileSystemWatcher::fileChanged, this, &AgentManager::agentExeChanged);
 #endif
 }
 
@@ -120,8 +119,8 @@ void AgentManager::continueStartup()
         QFileSystemWatcher *watcher = new QFileSystemWatcher(this);
         watcher->addPath(path);
 
-        connect(watcher, SIGNAL(directoryChanged(QString)),
-                this, SLOT(updatePluginInfos()));
+        connect(watcher, &QFileSystemWatcher::directoryChanged,
+                this, &AgentManager::updatePluginInfos);
     }
 #endif
 
@@ -540,7 +539,7 @@ void AgentManager::readPluginInfos(const QDir &directory)
             }
 
             if (agentInfo.launchMethod == AgentType::Process) {
-                const QString executable = Akonadi::XdgBaseDirs::findExecutableFile(agentInfo.exec);
+                const QString executable = Akonadi::StandardDirs::findExecutable(agentInfo.exec);
                 if (executable.isEmpty()) {
                     qCWarning(AKONADICONTROL_LOG) << "Executable" << agentInfo.exec << "for agent" << agentInfo.identifier << "could not be found!";
                     continue;
@@ -560,7 +559,7 @@ void AgentManager::readPluginInfos(const QDir &directory)
 
 QStringList AgentManager::pluginInfoPathList()
 {
-    return Akonadi::XdgBaseDirs::findAllResourceDirs("data", QStringLiteral("akonadi/agents"));
+    return Akonadi::StandardDirs::locateAllResourceDirs(QStringLiteral("akonadi/agents"));
 }
 
 void AgentManager::load()
@@ -568,7 +567,7 @@ void AgentManager::load()
     org::freedesktop::Akonadi::ResourceManager resmanager(Akonadi::DBus::serviceName(Akonadi::DBus::Server), QStringLiteral("/ResourceManager"), QDBusConnection::sessionBus(), this);
     const QStringList knownResources = resmanager.resourceInstances();
 
-    QSettings file(Akonadi::StandardDirs::agentConfigFile(Akonadi::XdgBaseDirs::ReadOnly), QSettings::IniFormat);
+    QSettings file(Akonadi::StandardDirs::agentsConfigFile(Akonadi::StandardDirs::ReadOnly), QSettings::IniFormat);
     file.beginGroup(QStringLiteral("Instances"));
     const QStringList entries = file.childGroups();
     for (int i = 0; i < entries.count(); ++i) {
@@ -609,7 +608,7 @@ void AgentManager::load()
 
 void AgentManager::save()
 {
-    QSettings file(Akonadi::StandardDirs::agentConfigFile(Akonadi::XdgBaseDirs::WriteOnly), QSettings::IniFormat);
+    QSettings file(Akonadi::StandardDirs::agentsConfigFile(Akonadi::StandardDirs::WriteOnly), QSettings::IniFormat);
 
     for (const AgentType &info : qAsConst(mAgents)) {
         info.save(&file);
