@@ -52,7 +52,7 @@ public:
     void collectionCreateResult(KJob *job);   // slot
 
     SpecialCollectionsRequestJob *q;
-    SpecialCollections *mSpecialCollections;
+    SpecialCollections *mSpecialCollections = nullptr;
     int mPendingCreateJobs;
 
     QByteArray mRequestedType;
@@ -92,7 +92,7 @@ bool SpecialCollectionsRequestJobPrivate::isEverythingReady()
             if (it.value() && !mSpecialCollections->hasDefaultCollection(it.key())) {
                 return false;
             }
-            it++;
+            ++it;
         }
     }
 
@@ -347,7 +347,7 @@ void SpecialCollectionsRequestJob::doStart()
         emitResult();
     } else {
         GetLockJob *lockJob = new GetLockJob(this);
-        connect(lockJob, SIGNAL(result(KJob*)), this, SLOT(lockResult(KJob*)));
+        connect(lockJob, &GetLockJob::result, this, [this](KJob*job) { d->lockResult(job);});
         lockJob->start();
     }
 }
