@@ -132,7 +132,7 @@ void TransactionSequence::slotResult(KJob *job)
                 }
                 d->mState = TransactionSequencePrivate::Committing;
                 TransactionCommitJob *job = new TransactionCommitJob(this);
-                connect(job, &TransactionCommitJob::result, [this, d](KJob *job) { d->commitResult(job);});
+                connect(job, &TransactionCommitJob::result, [d](KJob *job) { d->commitResult(job);});
             } else if (d->mState == TransactionSequencePrivate::RollingBack) {
                 emitResult();
             }
@@ -156,7 +156,7 @@ void TransactionSequence::slotResult(KJob *job)
             }
             d->mState = TransactionSequencePrivate::RollingBack;
             TransactionRollbackJob *job = new TransactionRollbackJob(this);
-            connect(job, &TransactionRollbackJob::result, [this, d](KJob *job) { d->rollbackResult(job);});
+            connect(job, &TransactionRollbackJob::result, this, [d](KJob *job) { d->rollbackResult(job);});
         }
     }
 }
@@ -184,11 +184,11 @@ void TransactionSequence::commit()
         if (!error()) {
             d->mState = TransactionSequencePrivate::Committing;
             TransactionCommitJob *job = new TransactionCommitJob(this);
-            connect(job, &TransactionCommitJob::result, [this, d](KJob *job) { d->commitResult(job);});
+            connect(job, &TransactionCommitJob::result, this, [d](KJob *job) { d->commitResult(job);});
         } else {
             d->mState = TransactionSequencePrivate::RollingBack;
             TransactionRollbackJob *job = new TransactionRollbackJob(this);
-            connect(job, &TransactionRollbackJob::result, [this, d](KJob *job) { d->rollbackResult(job);});
+            connect(job, &TransactionRollbackJob::result, this, [d](KJob *job) { d->rollbackResult(job);});
         }
     }
 }
@@ -237,7 +237,7 @@ void TransactionSequence::rollback()
 
     d->mState = TransactionSequencePrivate::RollingBack;
     TransactionRollbackJob *job = new TransactionRollbackJob(this);
-    connect(job, &TransactionRollbackJob::result, [this, d](KJob *job) { d->rollbackResult(job);});
+    connect(job, &TransactionRollbackJob::result, this, [d](KJob *job) { d->rollbackResult(job);});
 }
 
 #include "moc_transactionsequence.cpp"
