@@ -1,6 +1,6 @@
 /*
     Copyright (c) 2009 Stephen Kelly <steveire@gmail.com>
-    Copyright (C) 2012-2017 Laurent Montel <montel@kde.org>
+    Copyright (C) 2012-2018 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -37,7 +37,6 @@ class RecursiveCollectionFilterProxyModelPrivate
 public:
     RecursiveCollectionFilterProxyModelPrivate(RecursiveCollectionFilterProxyModel *model)
         : q_ptr(model)
-        , checkOnlyChecked(false)
     {
 
     }
@@ -45,7 +44,7 @@ public:
     QSet<QString> includedMimeTypes;
     Akonadi::MimeTypeChecker checker;
     QString pattern;
-    bool checkOnlyChecked;
+    bool checkOnlyChecked = false;
 };
 
 }
@@ -134,13 +133,17 @@ int Akonadi::RecursiveCollectionFilterProxyModel::columnCount(const QModelIndex
 void Akonadi::RecursiveCollectionFilterProxyModel::setSearchPattern(const QString &pattern)
 {
     Q_D(RecursiveCollectionFilterProxyModel);
-    d->pattern = pattern;
-    invalidate();
+    if (d->pattern != pattern) {
+        d->pattern = pattern;
+        invalidate();
+    }
 }
 
 void Akonadi::RecursiveCollectionFilterProxyModel::setIncludeCheckedOnly(bool checked)
 {
     Q_D(RecursiveCollectionFilterProxyModel);
-    d->checkOnlyChecked = checked;
-    invalidate();
+    if (d->checkOnlyChecked != checked) {
+        d->checkOnlyChecked = checked;
+        invalidate();
+    }
 }
