@@ -192,15 +192,11 @@ public:
      */
     void invalidateTagCache(qint64 tagId);
 
-    /**
-     * This method is called by the ChangeMediator to update pending items with the outgoing changes.
-     * Currently this only serves to set RID on pending item notifications.
-     */
-    void updatePendingItem(const Akonadi::Item &item);
-
     void scheduleSubscriptionUpdate();
     void slotUpdateSubscription();
 
+    static Protocol::ModifySubscriptionCommand::ChangeType monitorTypeToProtocol(Monitor::Type type);
+
     /**
       @brief Class used to determine when to purge items in a Collection
 
