@@ -25,6 +25,7 @@
 #include "collectionutils.h"
 #include "item.h"
 #include "itemfetchscope.h"
+#include "collectionfetchscope.h"
 #include "sharedvaluepool_p.h"
 #include "tag.h"
 
@@ -121,6 +122,8 @@ public:
     */
     static Collection parseCollection(const Protocol::FetchCollectionsResponse &data, bool requireParent = true);
 
+    static Tag parseTag(const Protocol::FetchTagsResponse &data);
+
     static void parseAttributes(const Protocol::Attributes &attributes, Item *item);
     static void parseAttributes(const Protocol::Attributes &attributes, Collection *collection);
     static void parseAttributes(const Protocol::Attributes &attributes, Tag *entity);
@@ -222,12 +225,14 @@ public:
     /**
       Converts a given ItemFetchScope object into a protocol representation.
     */
-    static Protocol::FetchScope itemFetchScopeToProtocol(const ItemFetchScope &fetchScope);
+    static Protocol::ItemFetchScope itemFetchScopeToProtocol(const ItemFetchScope &fetchScope);
+    static ItemFetchScope parseItemFetchScope(const Protocol::ItemFetchScope &fetchScope);
 
-    /**
-      Converts a given TagFetchScope object into a protocol representation.
-    */
-    static QVector<QByteArray> tagFetchScopeToProtocol(const TagFetchScope &fetchScope);
+    static Protocol::CollectionFetchScope collectionFetchScopeToProtocol(const CollectionFetchScope &fetchScope);
+    static CollectionFetchScope parseCollectionFetchScope(const Protocol::CollectionFetchScope &fetchScope);
+
+    static Protocol::TagFetchScope tagFetchScopeToProtocol(const TagFetchScope &fetchScope);
+    static TagFetchScope parseTagFetchScope(const Protocol::TagFetchScope &fetchScope);
 
     /**
       Parses a single line from an item fetch job result into an Item object.
