@@ -19,6 +19,7 @@
 
 #include "tag.h"
 #include "tag_p.h"
+#include "akonadicore_debug.h"
 
 #include "tagattribute.h"
 #include <QUuid>
@@ -256,3 +257,13 @@ Tag Tag::genericTag(const QString &name)
     tag.setName(name);
     return tag;
 }
+
+bool Tag::checkAttribute(Attribute *attr, const QByteArray &type) const
+{
+    if (attr) {
+        return true;
+    }
+    qCWarning(AKONADICORE_LOG) << "Found attribute of unknown type" << type
+                               << ". Did you forget to call AttributeFactory::registerAttribute()?";
+    return false;
+}
