@@ -21,6 +21,8 @@
 #include "scope_p.h"
 #include "datastream_p_p.h"
 
+#include <QJsonArray>
+#include <QJsonObject>
 #include <QStringList>
 
 #include "imapset_p.h"
@@ -104,6 +106,12 @@ bool Scope::HRID::operator==(const HRID &other) const
     return id == other.id && remoteId == other.remoteId;
 }
 
+void Scope::HRID::toJson(QJsonObject &json) const
+{
+    json[QStringLiteral("ID")] = id;
+    json[QStringLiteral("RemoteID")] = remoteId;
+}
+
 Scope::Scope()
     : d(new ScopePrivate)
 {
@@ -305,6 +313,40 @@ QString Scope::gid() const
     return d->gidSet.at(0);
 }
 
+void Scope::toJson(QJsonObject &json) const
+{
+    switch (scope()) {
+    case Scope::Uid:
+        json[QStringLiteral("type")] = QStringLiteral("UID");
+        json[QStringLiteral("value")] = QString::fromUtf8(uidSet().toImapSequenceSet());
+        break;
+    case Scope::Rid:
+        json[QStringLiteral("type")] = QStringLiteral("RID");
+        json[QStringLiteral("value")] = QJsonArray::fromStringList(ridSet());
+        break;
+    case Scope::Gid:
+        json[QStringLiteral("type")] = QStringLiteral("GID");
+        json[QStringLiteral("value")] = QJsonArray::fromStringList(gidSet());
+        break;
+    case Scope::HierarchicalRid:
+        {
+            const auto &chain = hridChain();
+            QJsonArray hridArray;
+            for (const auto &hrid : chain) {
+                QJsonObject obj;
+                hrid.toJson(obj);
+                hridArray.append(obj);
+            }
+            json[QStringLiteral("type")] = QStringLiteral("HRID");
+            json[QStringLiteral("value")] = hridArray;
+        }
+        break;
+    default:
+        json[QStringLiteral("type")] = QStringLiteral("invalid");
+        json[QStringLiteral("value")] = QJsonValue(static_cast<int>(scope()));
+    }
+}
+
 Protocol::DataStream &operator<<(Protocol::DataStream &stream, const Akonadi::Scope &scope)
 {
     stream << (quint8) scope.d->scope;
