@@ -58,6 +58,9 @@ public:
      */
     IntervalCheck *intervalChecker();
 
+    /**
+     * Instance-aware server .config directory
+     */
     QString serverPath() const;
 
     /**
@@ -102,7 +105,7 @@ protected:
     QProcess *mDatabaseProcess = nullptr;
     QVector<Connection *> mConnections;
     SearchManager *mSearchManager = nullptr;
-    bool mAlreadyShutdown;
+    bool mAlreadyShutdown = false;
 
     static AkonadiServer *s_instance;
 };
