@@ -30,10 +30,12 @@
 #include "entities.h"
 #include "global.h"
 #include "commandcontext.h"
+#include "tracer.h"
 
 #include <private/protocol_p.h>
+#include <private/datastream_p_p.h>
 
-class QEventLoop;
+#include <memory>
 
 namespace Akonadi
 {
@@ -56,6 +58,8 @@ public:
     explicit Connection(quintptr socketDescriptor, QObject *parent = nullptr);
     ~Connection() override;
 
+    static Connection *self();
+
     virtual DataStore *storageBackend();
 
     CollectionReferenceManager *collectionReferenceManager();
@@ -76,8 +80,13 @@ public:
 
     Protocol::CommandPtr readCommand();
 
-public Q_SLOTS:
-    virtual void sendResponse(const Protocol::CommandPtr &response);
+    void setState(ConnectionState state);
+
+    template<typename T>
+    inline typename std::enable_if<std::is_base_of<Protocol::Command, T>::value>::type
+    sendResponse(T &&response);
+
+    void sendResponse(qint64 tag, const Protocol::CommandPtr &response);
 
 Q_SIGNALS:
     void disconnected();
@@ -86,7 +95,6 @@ Q_SIGNALS:
 protected Q_SLOTS:
     void handleIncomingData();
 
-    void slotConnectionStateChange(ConnectionState state);
     void slotConnectionIdle();
     void slotSocketDisconnected();
     void slotSendHello();
@@ -94,43 +102,73 @@ protected Q_SLOTS:
 protected:
     Connection(QObject *parent = nullptr); // used for testing
 
-    virtual void init() override;
-    virtual void quit() override;
+    void init() override;
+    void quit() override;
 
-    virtual Handler *findHandlerForCommand(Protocol::Command::Type cmd);
+    Handler *findHandlerForCommand(Protocol::Command::Type cmd);
+
+    qint64 currentTag() const;
 
 protected:
-    quintptr m_socketDescriptor;
+    quintptr m_socketDescriptor = {};
     QLocalSocket *m_socket = nullptr;
-    QPointer<Handler> m_currentHandler;
-    ConnectionState m_connectionState;
+    std::unique_ptr<Handler> m_currentHandler;
+    ConnectionState m_connectionState = NonAuthenticated;
     mutable DataStore *m_backend = nullptr;
     QList<QByteArray> m_statusMessageQueue;
     QString m_identifier;
     QByteArray m_sessionId;
-    bool m_verifyCacheOnRetrieval;
+    bool m_verifyCacheOnRetrieval = false;
     CommandContext m_context;
     QTimer *m_idleTimer = nullptr;
-    QEventLoop *m_waitLoop = nullptr;
 
     QTime m_time;
-    qint64 m_totalTime;
+    qint64 m_totalTime = 0;
     QHash<QString, qint64> m_totalTimeByHandler;
     QHash<QString, qint64> m_executionsByHandler;
 
-    bool m_connectionClosing;
+    bool m_connectionClosing = false;
 
 private:
-    void sendResponse(qint64 tag, const Protocol::CommandPtr &response);
+    template<typename T>
+    inline typename std::enable_if<std::is_base_of<Protocol::Command, T>::value>::type
+    sendResponse(qint64 tag, T &&response);
 
     /** For debugging */
     void startTime();
     void stopTime(const QString &identifier);
     void reportTime() const;
-    bool m_reportTime;
+    bool m_reportTime = false;
 
 };
 
+template<typename T>
+inline typename std::enable_if<std::is_base_of<Protocol::Command, T>::value>::type
+Connection::sendResponse(T &&response)
+{
+    sendResponse<T>(currentTag(), std::move(response));
+}
+
+template<typename T>
+inline typename std::enable_if<std::is_base_of<Protocol::Command, T>::value>::type
+Connection::sendResponse(qint64 tag, T &&response)
+{
+    if (Tracer::self()->currentTracer() != QLatin1String("null")) {
+        Tracer::self()->connectionOutput(m_identifier, tag, response);
+    }
+    Protocol::DataStream stream(m_socket);
+    stream << tag;
+    stream << std::move(response);
+    if (!m_socket->waitForBytesWritten()) {
+        if (m_socket->state() == QLocalSocket::ConnectedState) {
+            throw ProtocolException("Server write timeout");
+        } else {
+            // The client has disconnected before we managed to send our response,
+            // which is not an error
+        }
+    }
+}
+
 } // namespace Server
 } // namespace Akonadi
 
