@@ -37,8 +37,9 @@ namespace Server
 */
 class ColMove : public Handler
 {
-    Q_OBJECT
 public:
+    ~ColMove() override = default;
+
     bool parseStream() override;
 };
 
