@@ -34,8 +34,9 @@ namespace Server
 */
 class SearchPersistent : public Handler
 {
-    Q_OBJECT
 public:
+    ~SearchPersistent() override = default;
+
     bool parseStream() override;
 };
 
