@@ -29,8 +29,9 @@ namespace Server
 
 class TagRemove : public Handler
 {
-    Q_OBJECT
 public:
+    ~TagRemove() override = default;
+
     bool parseStream() override;
 };
 
