@@ -34,10 +34,9 @@ namespace Server
 */
 class TransactionHandler : public Handler
 {
-    Q_OBJECT
-    Q_ENUMS(Mode)
-
 public:
+    ~TransactionHandler() override = default;
+
     bool parseStream() override;
 };
 
