@@ -37,7 +37,6 @@ namespace Protocol
 class Ancestor;
 class CachePolicy;
 class FetchCollectionsResponse;
-using FetchCollectionsResponsePtr = QSharedPointer<FetchCollectionsResponse>;
 class FetchTagsResponse;
 using FetchTagsResponsePtr = QSharedPointer<FetchTagsResponse>;
 class FetchRelationsResponse;
@@ -77,14 +76,14 @@ public:
       Make sure DataStore::activeCachePolicy() has been called before to include
       the effective cache policy
     */
-    static Protocol::FetchCollectionsResponsePtr fetchCollectionsResponse(const Collection &col);
+    static Protocol::FetchCollectionsResponse fetchCollectionsResponse(const Collection &col);
 
     /**
       Returns the protocol representation of the given collection.
       Make sure DataStore::activeCachePolicy() has been called before to include
       the effective cache policy
     */
-    static Protocol::FetchCollectionsResponsePtr fetchCollectionsResponse(const Collection &col,
+    static Protocol::FetchCollectionsResponse fetchCollectionsResponse(const Collection &col,
             const CollectionAttribute::List &attributeList,
             bool includeStatistics = false,
             int ancestorDepth = 0,
@@ -100,11 +99,11 @@ public:
             const QStack<Collection> &ancestors,
             const QStack<CollectionAttribute::List> &_ancestorsAttributes = QStack<CollectionAttribute::List>());
 
-    static Protocol::FetchTagsResponsePtr fetchTagsResponse(const Tag &tag,
+    static Protocol::FetchTagsResponse fetchTagsResponse(const Tag &tag,
             bool withRID = false,
             Connection *connection = nullptr);
 
-    static Protocol::FetchRelationsResponsePtr fetchRelationsResponse(const Relation &relation);
+    static Protocol::FetchRelationsResponse fetchRelationsResponse(const Relation &relation);
 
     /**
       Converts a bytearray list of flag names into flag records.
