@@ -21,7 +21,6 @@
 #include "utils.h"
 #include "akonadiserver_debug.h"
 
-#include <private/xdgbasedirs_p.h>
 #include <private/standarddirs_p.h>
 
 #include <QDir>
@@ -29,6 +28,7 @@
 #include <QSqlDriver>
 #include <QSqlError>
 #include <QSqlQuery>
+#include <QStandardPaths>
 
 #include <config-akonadi.h>
 #ifdef HAVE_UNISTD_H
@@ -96,9 +96,8 @@ bool DbConfigPostgresql::init(QSettings &settings)
             }
         }
         postgresSearchPath.append(postgresVersionedSearchPaths);
-
-        defaultServerPath = XdgBaseDirs::findExecutableFile(QStringLiteral("pg_ctl"), postgresSearchPath);
-        defaultInitDbPath = XdgBaseDirs::findExecutableFile(QStringLiteral("initdb"), postgresSearchPath);
+        defaultServerPath = QStandardPaths::findExecutable(QStringLiteral("pg_ctl"), postgresSearchPath);
+        defaultInitDbPath = QStandardPaths::findExecutable(QStringLiteral("initdb"), postgresSearchPath);
         defaultHostName = Utils::preferredSocketDirectory(StandardDirs::saveDir("data", QStringLiteral("db_misc")));
         defaultPgData = StandardDirs::saveDir("data", QStringLiteral("db_data"));
     }
