@@ -334,6 +334,15 @@ void QueryBuilder::buildQuery(QString *statement)
     if (mLimit > 0) {
         *statement += QLatin1Literal(" LIMIT ") + QString::number(mLimit);
     }
+
+    if (mType == Select && mForUpdate) {
+        if (mDatabaseType == DbType::Sqlite) {
+            // SQLite does not support SELECT ... FOR UPDATE syntax, because it does
+            // table-level locking
+        } else {
+            *statement += QLatin1Literal(" FOR UPDATE");
+        }
+    }
 }
 
 bool QueryBuilder::retryLastTransaction(bool rollback)
@@ -616,3 +625,8 @@ qint64 QueryBuilder::insertId()
     }
     return -1;
 }
+
+void QueryBuilder::setForUpdate(bool forUpdate)
+{
+    mForUpdate = forUpdate;
+}
